@@ -7,13 +7,20 @@ from ..shared import NumType
 from ..utils import AutoValueEnum
 
 
-class Polarizations(str, AutoValueEnum):
+class PolarizationEnum(str, AutoValueEnum):
     HH = auto()
     VV = auto()
     HV = auto()
     VH = auto()
 
 
+class Polarizations(BaseModel):
+    __root__: List[PolarizationEnum]
+
+    def __getitem__(self, item):
+        return self.__root__[item].value
+
+
 class FrequencyBands(str, AutoValueEnum):
     """
     https://github.com/radiantearth/stac-spec/tree/v0.9.0/extensions/sar#common-frequency-band-names
@@ -44,9 +51,8 @@ class SARExtension(BaseModel):
     """
 
     instrument_mode: str
-    frequency_band: FrequencyBands
     center_frequency: Optional[NumType]
-    polarizations: List[Polarizations]
+    polarizations: Polarizations
     product_type: str
     resolution_range: Optional[int]
     resolution_azimuth: Optional[int]
@@ -54,10 +60,11 @@ class SARExtension(BaseModel):
     pixel_spacing_azimuth: Optional[int]
     looks_range: Optional[int]
     looks_azimuth: Optional[NumType]
-    looks_equivalent_number: Optional[int]
+    looks_equivalent_number: Optional[NumType]
     observation_direction: Optional[ObservationDirections]
+    frequency_band: FrequencyBands
 
     class Config:
-        use_enum_values = True
         allow_population_by_field_name = True
         alias_generator = lambda field_name: f"sar:{field_name}"
+        use_enum_values = True
