@@ -21,13 +21,10 @@ class SatelliteExtension(BaseModel):
     https://github.com/radiantearth/stac-spec/tree/v0.9.0/extensions/sat#satellite-extension-specification
     """
 
-    orbit_state: Optional[OrbitStates] = Field(None, alias="sat:orbite_state")
-    relative_orbit: Optional[int] = Field(None, alias="sat:relative_orbit")
-    platform: Optional[str]
-    instruments: Optional[List[str]]
-    constellation: Optional[str]
-    mission: Optional[str]
+    orbit_state: Optional[OrbitStates]
+    relative_orbit: Optional[int]
 
     class Config:
         use_enum_values = True
         allow_population_by_field_name = True
+        alias_generator = lambda field_name: f"sat:{field_name}"
